@@ -75,6 +75,14 @@ def load_libtiepie():
     api.LstDevGetCalibrationDate.argtypes = [c_uint32, c_uint32]
     api.LstDevGetSerialNumber.restype = c_uint32
     api.LstDevGetSerialNumber.argtypes = [c_uint32, c_uint32]
+    api.LstDevGetIPv4Address.restype = c_uint32
+    api.LstDevGetIPv4Address.argtypes = [c_uint32, c_uint32]
+    api.LstDevGetIPPort.restype = c_uint16
+    api.LstDevGetIPPort.argtypes = [c_uint32, c_uint32]
+    api.LstDevHasServer.restype = c_uint8
+    api.LstDevHasServer.argtypes = [c_uint32, c_uint32]
+    api.LstDevGetServer.restype = c_uint32
+    api.LstDevGetServer.argtypes = [c_uint32, c_uint32]
     api.LstDevGetTypes.restype = c_uint32
     api.LstDevGetTypes.argtypes = [c_uint32, c_uint32]
     api.LstDevGetContainedSerialNumbers.restype = c_uint32
@@ -123,6 +131,30 @@ def load_libtiepie():
         api.LstSetMessageDeviceRemoved.argtypes = [HWND]
         api.LstSetMessageDeviceCanOpenChanged.restype = None
         api.LstSetMessageDeviceCanOpenChanged.argtypes = [HWND]
+    api.NetGetAutoDetectEnabled.restype = c_uint8
+    api.NetGetAutoDetectEnabled.argtypes = []
+    api.NetSetAutoDetectEnabled.restype = c_uint8
+    api.NetSetAutoDetectEnabled.argtypes = [c_uint8]
+    api.NetSrvAdd.restype = c_uint8
+    api.NetSrvAdd.argtypes = [c_char_p, c_uint32, c_void_p]
+    api.NetSrvRemove.restype = c_uint8
+    api.NetSrvRemove.argtypes = [c_char_p, c_uint32, c_uint8]
+    api.NetSrvGetCount.restype = c_uint32
+    api.NetSrvGetCount.argtypes = []
+    api.NetSrvGetByIndex.restype = c_uint32
+    api.NetSrvGetByIndex.argtypes = [c_uint32]
+    api.NetSrvGetByURL.restype = c_uint32
+    api.NetSrvGetByURL.argtypes = [c_char_p, c_uint32]
+    api.NetSrvSetCallbackAdded.restype = None
+    api.NetSrvSetCallbackAdded.argtypes = [CallbackHandle, c_void_p]
+    if platform.system() == 'Linux':
+        api.NetSrvSetEventAdded.restype = None
+        api.NetSrvSetEventAdded.argtypes = [c_int]
+    if platform.system() == 'Windows':
+        api.NetSrvSetEventAdded.restype = None
+        api.NetSrvSetEventAdded.argtypes = [HANDLE]
+        api.NetSrvSetMessageAdded.restype = None
+        api.NetSrvSetMessageAdded.argtypes = [HWND]
     api.ObjClose.restype = None
     api.ObjClose.argtypes = [c_uint32]
     api.ObjIsRemoved.restype = c_uint8
@@ -155,6 +187,10 @@ def load_libtiepie():
     api.DevGetCalibrationToken.argtypes = [c_uint32, c_char_p, c_uint32]
     api.DevGetSerialNumber.restype = c_uint32
     api.DevGetSerialNumber.argtypes = [c_uint32]
+    api.DevGetIPv4Address.restype = c_uint32
+    api.DevGetIPv4Address.argtypes = [c_uint32]
+    api.DevGetIPPort.restype = c_uint16
+    api.DevGetIPPort.argtypes = [c_uint32]
     api.DevGetProductId.restype = c_uint32
     api.DevGetProductId.argtypes = [c_uint32]
     api.DevGetVendorId.restype = c_uint32
@@ -167,6 +203,20 @@ def load_libtiepie():
     api.DevGetNameShort.argtypes = [c_uint32, c_char_p, c_uint32]
     api.DevGetNameShortest.restype = c_uint32
     api.DevGetNameShortest.argtypes = [c_uint32, c_char_p, c_uint32]
+    api.DevHasBattery.restype = c_uint8
+    api.DevHasBattery.argtypes = [c_uint32]
+    api.DevGetBatteryCharge.restype = c_int8
+    api.DevGetBatteryCharge.argtypes = [c_uint32]
+    api.DevGetBatteryTimeToEmpty.restype = c_int32
+    api.DevGetBatteryTimeToEmpty.argtypes = [c_uint32]
+    api.DevGetBatteryTimeToFull.restype = c_int32
+    api.DevGetBatteryTimeToFull.argtypes = [c_uint32]
+    api.DevIsBatteryChargerConnected.restype = c_uint8
+    api.DevIsBatteryChargerConnected.argtypes = [c_uint32]
+    api.DevIsBatteryCharging.restype = c_uint8
+    api.DevIsBatteryCharging.argtypes = [c_uint32]
+    api.DevIsBatteryBroken.restype = c_uint8
+    api.DevIsBatteryBroken.argtypes = [c_uint32]
     api.DevSetCallbackRemoved.restype = None
     api.DevSetCallbackRemoved.argtypes = [c_uint32, Callback, c_void_p]
     if platform.system() == 'Linux':
@@ -917,6 +967,32 @@ def load_libtiepie():
     api.I2CSetSpeed.argtypes = [c_uint32, c_double]
     api.I2CVerifySpeed.restype = c_double
     api.I2CVerifySpeed.argtypes = [c_uint32, c_double]
+    api.SrvConnect.restype = c_uint8
+    api.SrvConnect.argtypes = [c_uint32, c_uint8]
+    api.SrvDisconnect.restype = c_uint8
+    api.SrvDisconnect.argtypes = [c_uint32, c_uint8]
+    api.SrvRemove.restype = c_uint8
+    api.SrvRemove.argtypes = [c_uint32, c_uint8]
+    api.SrvGetStatus.restype = c_uint32
+    api.SrvGetStatus.argtypes = [c_uint32]
+    api.SrvGetLastError.restype = c_uint32
+    api.SrvGetLastError.argtypes = [c_uint32]
+    api.SrvGetURL.restype = c_uint32
+    api.SrvGetURL.argtypes = [c_uint32, c_char_p, c_uint32]
+    api.SrvGetID.restype = c_uint32
+    api.SrvGetID.argtypes = [c_uint32, c_char_p, c_uint32]
+    api.SrvGetIPv4Address.restype = c_uint32
+    api.SrvGetIPv4Address.argtypes = [c_uint32]
+    api.SrvGetIPPort.restype = c_uint16
+    api.SrvGetIPPort.argtypes = [c_uint32]
+    api.SrvGetName.restype = c_uint32
+    api.SrvGetName.argtypes = [c_uint32, c_char_p, c_uint32]
+    api.SrvGetDescription.restype = c_uint32
+    api.SrvGetDescription.argtypes = [c_uint32, c_char_p, c_uint32]
+    api.SrvGetVersion.restype = c_uint64
+    api.SrvGetVersion.argtypes = [c_uint32]
+    api.SrvGetVersionExtra.restype = c_uint32
+    api.SrvGetVersionExtra.argtypes = [c_uint32, c_char_p, c_uint32]
     api.HlpPointerArrayNew.restype = c_void_p
     api.HlpPointerArrayNew.argtypes = [c_uint32]
     api.HlpPointerArraySet.restype = None
